##  Conditional Relations Between Fact Sheet Subtypes
You can create a relation between specific fact sheet subtypes by using conditional relations. To learn more about conditional attributes, see [Conditional Attributes](https://help.sap.com/docs/leanix/ea/conditional-attributes?locale=en-US&state=PRODUCTION&version=CLOUD "Conditional attributes allow fields and relations in fact sheets to be visible based on related field values. Conditional attributes enables tailoring of attributes for subtypes, streamlining subtype management.").
In this section, you'll learn how to create a conditional relation between:
  * Subtypes of different fact sheet types
  * Subtypes of the same fact sheet type
